@@ -2,11 +2,19 @@ class PlyException(Exception):
     pass
 
 
+class AlreadyLinkedToPatchRepo(PlyException):
+    pass
+
+
 class NoLinkedPatchRepo(PlyException):
     pass
 
 
-class AlreadyLinkedToPatchRepo(PlyException):
+class NoPatchesApplied(PlyException):
+    pass
+
+
+class NothingToResolve(PlyException):
     pass
 
 
